@@ -5,7 +5,7 @@
 #' man/` folder. This function extracts those examples into a list of character
 #' vectors, one list element for each documented function.
 #'
-#' Anything examples found within a `\\dontrun\{...\}` block are ignored.
+#' Anything found within a `\\dontrun\{...\}` block is ignored.
 #'
 #' @param r_file_name The name of the `.R` file within `R/`. There's no need to
 #'   specify the file path (as `R/x.R`, but you can do this if you want), you
@@ -25,7 +25,7 @@
 #' exampletestr::extract_examples("exemplar")
 #' exampletestr::extract_examples("exemplar")
 #' setwd("..")
-#' filesstrings::RemoveDirs("tempkg")
+#' filesstrings::dir.remove("tempkg")
 #' \dontrun{
 #' extract_examples("non_existent_file")}
 #'
@@ -33,25 +33,25 @@
 #' @export
 extract_examples <- function(r_file_name, pkg_dir = ".") {
   if (stringr::str_detect(r_file_name, "/")) {
-    r_file_name <- filesstrings::StrAfterNth(r_file_name, "/", -1)
+    r_file_name <- filesstrings::str_after_nth(r_file_name, "/", -1)
   }
   r_file_name <- stringr::str_c(pkg_dir, "/R/", r_file_name) %>%
-    filesstrings::GiveExt("R")
+    filesstrings::give_ext("R")
   r_file_lines_quotes_gone <- readLines(r_file_name) %>%
     formatR::tidy_source(text = ., comment = FALSE, arrow = TRUE,
                          output = FALSE, width.cutoff = 500) %>%
     getElement("text.tidy") %>%
     textConnection() %>%
     readLines() %>%
-    filesstrings::RemoveQuoted()
+    filesstrings::remove_quoted()
   r_file_funs <- stringr::str_match(r_file_lines_quotes_gone,
                                     "(^[^ ]*) <- function\\(")[, 2] %>%
     stats::na.omit()
   rd_file_paths <- list.files(paste0(pkg_dir, "/man"), pattern = "\\.Rd$") %>%
     paste0(pkg_dir, "/man/", .)
   rd_file_lines <- lapply(rd_file_paths, readLines)
-  rd_file_short_names <- rd_file_paths %>% filesstrings::BeforeLastDot() %>%
-    filesstrings::StrAfterNth("/", -1)
+  rd_file_short_names <- rd_file_paths %>% filesstrings::before_last_dot() %>%
+    filesstrings::str_after_nth("/", -1)
   names(rd_file_lines) <- rd_file_short_names
   documented_funs_in_alias_tags <- unlist(rd_file_lines) %>%
     stringr::str_extract("\\\\alias\\{.*\\}") %>%
@@ -71,11 +71,11 @@ extract_examples <- function(r_file_name, pkg_dir = ".") {
     purrr::map_chr(~ rd_file_short_names[.])
   wanted_rds <- unique(documented_where)
   wanted_rd_paths <- paste0(pkg_dir, "/man/",
-                            filesstrings::GiveExt(wanted_rds, "Rd"))
+                            filesstrings::give_ext(wanted_rds, "Rd"))
   examples <- lapply(wanted_rd_paths, extract_examples_rd)
   names(examples) <- wanted_rds
   ls_exs <- lengths(examples)
-  if (filesstrings::AllEqual(ls_exs, 0)) return(list(character(0)))
+  if (filesstrings::all_equal(ls_exs, 0)) return(list(character(0)))
   examples[as.logical(lengths(examples))]
 }
 
@@ -90,6 +90,7 @@ extract_examples <- function(r_file_name, pkg_dir = ".") {
 #' `plot(`, `ggplot(`, `set.seed` or `library(` are left alone, others are put
 #' in the shell of an `expect_equal()` statement. To prevent anything from being
 #' put in the shell of an `expect_equal()` statement, set `e_e = FALSE`.
+#' Anything found within a `\\dontrun\{...\}` block is ignored.
 #'
 #' @param example_block A character vector of the lines in the examples of a
 #'   function's documentation.
@@ -97,7 +98,7 @@ extract_examples <- function(r_file_name, pkg_dir = ".") {
 #' @param e_e Set this to `FALSE` to prevent anything from being put in the
 #'   shell of an `expect_equal()` statement.
 #'
-#' @return A character vector giving the shell of a test_that function call
+#' @return A character vector giving the shell of a `test_that` function call
 #'   testing all of the calls in the example block.
 #'
 #' @examples
@@ -111,16 +112,16 @@ extract_examples <- function(r_file_name, pkg_dir = ".") {
 #' exampletestr::make_test_shell(exampletestr::extract_examples("exemplar")[[1]],
 #'                               desc = "xyz", e_e = FALSE)
 #' setwd("..")
-#' filesstrings::RemoveDirs("tempkg")
+#' filesstrings::dir.remove("tempkg")
 #'
 #' @export
 make_test_shell <- function(example_block, desc = "", e_e = TRUE) {
   stopifnot(is.character(example_block))
-  if (filesstrings::AllEqual(example_block, character(0))) return(character(0))
+  if (filesstrings::all_equal(example_block, character(0))) return(character(0))
   expressions <- extract_expressions(example_block)
   if (e_e) {
     for_checking <- expressions %>%
-      lapply(filesstrings::RemoveQuoted) %>%
+      lapply(filesstrings::remove_quoted) %>%
       lapply(stringr::str_replace_all, " ", "")
     leave_alone <- vapply(for_checking, function(x) {
       any(stringr::str_detect(x,
@@ -145,11 +146,11 @@ make_test_shell <- function(example_block, desc = "", e_e = TRUE) {
 
 #' Create the shell of a test file.
 #'
-#' For a given `.R` file in the `R/` directory of a package, for each function
+#' For a given file `x.R` in the `R/` directory of a package, for each function
 #' defined in that `.R` file, `make_tests_shells_file` checks if there are
 #' examples for that function detailed in the `man/` directory (in a `.Rd` file)
-#' and if so creates a shell (skeleton) of a [testthat::test_that] test based on
-#' those examples. The created shells are then written to a file in
+#' and if so creates a shell (skeleton) of a [testthat::test_that()] test based on
+#' those examples via [make_test_shell()]. The created shells are then written to a file `test_x.R` in
 #' `tests/testthat`.
 #'
 #' @param r_file_name The name of the `.R` file within `R/`. There's no need to
@@ -171,7 +172,6 @@ make_test_shell <- function(example_block, desc = "", e_e = TRUE) {
 #' setwd(tempdir())
 #' devtools::create("tempkg")
 #' setwd("tempkg")
-#' devtools::use_testthat()
 #' file.copy(system.file("extdata", c("exemplar.R", "exampletestr.R"),
 #'                       package = "exampletestr"), "R")
 #' devtools::document()
@@ -179,7 +179,7 @@ make_test_shell <- function(example_block, desc = "", e_e = TRUE) {
 #' devtools::document()
 #' exampletestr::make_tests_shells_pkg(overwrite = TRUE)
 #' setwd("..")
-#' filesstrings::RemoveDirs("tempkg")
+#' filesstrings::dir.remove("tempkg")
 #'
 #' @export
 make_tests_shells_file <- function(r_file_name, pkg_dir = ".",
@@ -187,15 +187,11 @@ make_tests_shells_file <- function(r_file_name, pkg_dir = ".",
   current_wd <- getwd()
   on.exit(setwd(current_wd))
   setwd(pkg_dir)
-  if (!dir.exists("tests/testthat")) {
-    stop ("To use this function, your project directory must have a tests ",
-          "directory containing a testthat directory i.e. 'tests/testthat'. ",
-          "To start using testthat, run devtools::use_testthat().")
-  }
+  if (!dir.exists("tests/testthat")) devtools::use_testthat()
   if (stringr::str_detect(r_file_name, "/")) {
-    r_file_name <- filesstrings::StrAfterNth(r_file_name, "/", -1)
+    r_file_name <- filesstrings::str_after_nth(r_file_name, "/", -1)
   }
-  r_file_name <- filesstrings::GiveExt(r_file_name, "R")
+  r_file_name <- filesstrings::give_ext(r_file_name, "R")
   exampless <- extract_examples(r_file_name, pkg_dir = ".")
   not_making_message <- paste0("No examples found for file \"",
                                r_file_name, "\", ",
@@ -207,7 +203,7 @@ make_tests_shells_file <- function(r_file_name, pkg_dir = ".",
   }
   test_shells <- mapply(make_test_shell, SIMPLIFY = FALSE,
                         exampless, paste(names(exampless), "works"), e_e = e_e)
-  if (filesstrings::AllEqual(unique(test_shells), list(character(0)))) {
+  if (filesstrings::all_equal(unique(test_shells), list(character(0)))) {
     message(not_making_message)
     return(invisible(character(0)))
   }
@@ -224,7 +220,8 @@ make_tests_shells_file <- function(r_file_name, pkg_dir = ".",
 
 #' @rdname make_tests_shells_file
 #' @export
-make_tests_shells_pkg <- function(pkg_dir = ".", overwrite = FALSE, e_e = TRUE) {
+make_tests_shells_pkg <- function(pkg_dir = ".", overwrite = FALSE,
+                                  e_e = TRUE) {
   current_wd <- getwd()
   setwd(pkg_dir)
   on.exit(setwd(current_wd))
